/// <reference types="node" />
import JSZip from 'jszip';
import { ArchiveIndex, PartialTweetGDPR, PartialTweet, PartialTweetUser, InnerGDPRPersonalization, GPDRScreenNameHistory, GPDRProtectedHistory, InnerGDPRAgeInfo, GDPRMoment } from './TwitterTypes';
import DMArchive from './DMArchive';
import { EventTarget } from 'event-target-shim';
export declare type AcceptedZipSources = string | number[] | Uint8Array | ArrayBuffer | Blob | NodeJS.ReadableStream | JSZip;
export declare type ArchiveReadState = "idle" | "reading" | "indexing" | "tweet_read" | "user_read" | "dm_read" | "extended_read" | "ready";
export interface ExtendedGDPRInfo {
    followers: Set<string>;
    followings: Set<string>;
    favorites: Set<string>;
    mutes: Set<string>;
    blocks: Set<string>;
    lists: {
        created: string[];
        member_of: string[];
        subscribed: string[];
    };
    personalization: InnerGDPRPersonalization;
    screen_name_history: GPDRScreenNameHistory[];
    protected_history: GPDRProtectedHistory[];
    age_info: InnerGDPRAgeInfo;
    moments: GDPRMoment[];
}
export declare function dateFromTweet(tweet: PartialTweet): Date;
export declare function isWithMedia(tweet: PartialTweet): boolean;
export declare function isWithVideo(tweet: PartialTweet): boolean;
declare class Archive {
    protected _ready: Promise<void>;
    protected archive: JSZip;
    constructor(file: AcceptedZipSources);
    ready(): Promise<void>;
    dir(name: string): Archive;
    has(name: string): boolean;
    get(name: string, type?: "text" | "arraybuffer" | "blob", parse_auto?: boolean): Promise<any>;
    search(query: RegExp): JSZip.JSZipObject[];
    searchDir(query: RegExp): JSZip.JSZipObject[];
    read(file: JSZip.JSZipObject, type?: "text" | "arraybuffer" | "blob", parse_auto?: boolean): Promise<any>;
    ls(current_dir_only?: boolean): {
        [key: string]: JSZip.JSZipObject;
    };
}
declare type TwitterArchiveEvents = {
    zipready: CustomEvent<void>;
    userinfosready: CustomEvent<void>;
    tweetsread: CustomEvent<void>;
    indexready: CustomEvent<void>;
    willreaddm: CustomEvent<void>;
    willreadextended: CustomEvent<void>;
    ready: CustomEvent<void>;
    error: CustomEvent<any>;
};
declare type TwitterArchiveOnEvents = {
    onzipready: CustomEvent<void>;
    onuserinfosready: CustomEvent<void>;
    ontweetsread: CustomEvent<void>;
    onindexready: CustomEvent<void>;
    onwillreaddm: CustomEvent<void>;
    onwillreadextended: CustomEvent<void>;
    onready: CustomEvent<void>;
    onerror: CustomEvent<any>;
};
/**
 * Represents a full TwitterArchive. Support GDPR and classic archive.
 *
 * Remember that tweets, in searchs in particular are **NOT** sorted.
 *
 * Direct messages, parsed if archive is a GDPR archive, stored in `.messages`,
 * are returned and sorted from the most older to the more recent.
 */
export declare class TwitterArchive extends EventTarget<TwitterArchiveEvents, TwitterArchiveOnEvents> {
    protected _ready: Promise<void>;
    protected archive: Archive;
    state: ArchiveReadState;
    extended_gdpr: ExtendedGDPRInfo;
    protected _index: ArchiveIndex;
    protected dms: DMArchive;
    protected _is_gdpr: boolean;
    protected user_cache: PartialTweetUser;
    constructor(file: AcceptedZipSources, build_extended?: boolean);
    protected initGDPR(extended?: boolean): Promise<void>;
    protected initExtendedGDPR(): Promise<void>;
    protected convertToPartial(tweet: PartialTweetGDPR, pic_prof: string): PartialTweet;
    protected initClassic(): Promise<void>;
    protected isGDPRArchive(): boolean;
    isGDPRTweet(tweet: PartialTweetGDPR): true;
    isGDPRTweet(tweet: PartialTweet): false;
    month(month: string, year: string): PartialTweet[];
    between(since: Date, until: Date): PartialTweet[];
    id(id_str: string): PartialTweet | null;
    dmImage(name: string, is_group?: boolean): Promise<Blob>;
    readonly all: PartialTweet[];
    /** Access to the DMArchive */
    readonly messages: DMArchive;
    /** ID of the user who created this archive */
    readonly owner: string;
    /**
     * Screen name (@) of the user who created this archive.
     * May be obsolete (user can change screen_name over time).
     */
    readonly owner_screen_name: string;
    /** Not accurate in GDPR archive (will be the current date) */
    readonly generation_date: Date;
    readonly index: ArchiveIndex;
    readonly length: number;
    readonly is_gdpr: boolean;
    ready(): Promise<void>;
}
export {};
